@@ -13,13 +13,16 @@ class RealTimeClockServer(SensorServer):
                          streaming_interval=1000,
                          streaming_preferred_interval=1000)
 
+    def send_reading(self):
+        t = localtime()
+        fmt = JD_REAL_TIME_CLOCK_PACK_FORMATS[JD_REAL_TIME_CLOCK_REG_LOCAL_TIME]
+        self.send_report(JDPacket.packed(
+            JD_GET(JD_REAL_TIME_CLOCK_REG_LOCAL_TIME), fmt, t.tm_year, t.tm_mon, t.tm_mday, t.tm_wday, t.tm_hour, t.tm_min, t.tm_sec))
+
     def handle_packet(self, pkt: JDPacket):
         cmd = pkt.service_command
         if cmd == JD_GET(JD_REAL_TIME_CLOCK_REG_LOCAL_TIME):
-            t = localtime()
-            fmt = JD_REAL_TIME_CLOCK_PACK_FORMATS[JD_REAL_TIME_CLOCK_REG_LOCAL_TIME]
-            self.send_report(JDPacket.packed(
-                cmd, fmt, t.tm_year, t.tm_mon, t.tm_mday, t.tm_wday, t.tm_hour, t.tm_min, t.tm_sec))
+            self.send_reading()
         elif cmd == JD_GET(JD_REAL_TIME_CLOCK_REG_VARIANT):
             fmt = JD_REAL_TIME_CLOCK_PACK_FORMATS[JD_REAL_TIME_CLOCK_REG_VARIANT]
             self.send_report(JDPacket.packed(
